// Copyright 2011 Google Inc. All Rights Reserved.

/**
 * @fileoverview Implementation of the communication protocol between the webapp
 * and the native app.
 */
(function() {
  if (!navigator || navigator.offersNativeMessaging) {
    return;
  }

  var messagingApi = {
    apiVersion: 1
  };

  /**
   * Show a spinner.
   */
  messagingApi.showSpinner = function(show) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'showSpinner', {show: show});
  };

  /**
   * Purchase offer button was hit.
   */
  messagingApi.purchaseOffer = function(purchaseUrl) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'purchaseOffer', {purchaseUrl: purchaseUrl});
  };

  /**
   * Launch an external URL.
   */
  messagingApi.showExternalUrl = function(externalUrl) {
   navigator.googleInternal.dispatch('offersnativemessaging',
        'showExternalUrl', {externalUrl: externalUrl});
  };

  /**
   * An event has fired.
   */
  messagingApi.onEvent = function(eventType, msg) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'onEvent', {eventType: eventType, msg: msg});
  };

  /**
   * An error has occurred and the page cannot be rendered.
   */
  messagingApi.onError = function(errorType, msg, opt_rpcErrorCode) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'onError',
        {errorType: errorType, msg: msg, opt_rpcErrorCode: opt_rpcErrorCode});
  };

  /**
   * MOH has finished loading.
   */
  messagingApi.finishedLoading = function(whitelist) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'finishedLoading', {whitelist: whitelist});
  };

  /**
   * An offer has been purchased.
   */
  messagingApi.onPurchaseComplete = function(purchaseStatus, opt_rpcErrorCode) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'onPurchaseComplete',
        {purchaseStatus: purchaseStatus, opt_rpcErrorCode: opt_rpcErrorCode});
  };

  /**
   * MOH requests an analytics trackPageView call.
   */
  messagingApi.trackPageView = function(page) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'trackPageView', {page: page});
  };

  /**
   * MOH requests an analytics trackEvent call.
   */
  messagingApi.trackEvent = function(category, action, label, value) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'trackEvent',
        {category: category, action: action, label: label, value: value});
  };

  /**
   * MOH request Authentication.
   */
  messagingApi.authenticate = function(hash, authUrl) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'authenticate', {hash: hash, authUrl: authUrl});
  };

  /**
   * Alert the app of sharing data.
   */
  messagingApi.updateSharingContent =
      function(subject, body, opt_highlights, opt_detailsUrl, opt_imageUrl,
               opt_sharingId) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'updateSharingContent', {subject: subject, body: body,
        opt_highlights: opt_highlights, opt_detailsUrl: opt_detailsUrl,
        opt_imageUrl: opt_imageUrl, opt_sharingId: opt_sharingId});
  };

  /**
   * Push this url into URL history.
   */
  messagingApi.pushHistoryUrl = function(url) {
    navigator.googleInternal.dispatch('offersnativemessaging',
        'pushHistoryUrl', {url: url});
  };

  navigator.offersNativeMessaging = messagingApi;
})();
